@@ -1,15 +1,11 @@
 import asyncio
 import json
-import logging
+from dataclasses import dataclass
+from typing import Optional
 
 import httpx
 import websockets
 
-logger = logging.getLogger()
-
-from dataclasses import dataclass
-from typing import Optional
-
 from .helpers import req_wrap
 
 
